@@ -82,7 +82,8 @@ def get_delivery_order_status_dic():
         41: "No Retirable",
         42: "Viajando a CD",
         43: "Viajando B2B",
-        44: "Entregada B2B"
+        44: "Entregada B2B",
+        45: "Asignado Mensajero"
     }
 
 class LineOfBusinessType(Enum):
@@ -168,6 +169,7 @@ class DeliveryOrderStatusType(Enum):
     DistributionCenterTravelling = 42
     B2BTraveling = 43
     B2BDelivered = 44
+    DeliveryCourierAssigned = 45
     
 DELIVERY_ORDER_STATUS_TYPES = [e.value for e in DeliveryOrderStatusType]
 
@@ -218,6 +220,10 @@ DELIVERY_ORDER_STATE_MACHINE = {
     DeliveryOrderStatusType.SERReceived.value: [
         DeliveryOrderStatusType.DeliveryCourierReceived.value,
         DeliveryOrderStatusType.PhysicallyReceived.value,
+        DeliveryOrderStatusType.DeliveryCourierAssigned.value,
+    ],
+    DeliveryOrderStatusType.DeliveryCourierAssigned.value: [
+        DeliveryOrderStatusType.DeliveryCourierReceived.value,
     ],
     DeliveryOrderStatusType.DeliveryCourierReceived.value: [
         DeliveryOrderStatusType.DeliveryScheduled.value,
@@ -396,6 +402,86 @@ def _get_schedule_rejected_comments(event_info):
         return event_info['schedule_rejected_3_comments']
     return None
 
+def get_status_info_wom(delivery_order):
+    events_info, status, last_event_timestamp = None, None, None
+
+    if delivery_order['status'] == DeliveryOrderStatusType.PhysicallyReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Despacho recepcionado'
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2BReceptionRejected.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Orden Cancelada por Logística'
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2CTraveling.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Despacho en ruta'
+
+    elif delivery_order['status'] in [DeliveryOrderStatusType.NotDelivered.value, DeliveryOrderStatusType.NotDeliverable.value]:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = "Intento {}".format( str(delivery_order['delivery_attemps']) )
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.Delivered.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Entregado'
+
+    #elif delivery_order['status'] == DeliveryOrderStatusType.NotDeliverable.value:
+    #    events_info = filter(
+    #        lambda x: x['status'] == delivery_order['status'],
+    #        delivery_order['events_info']
+    #    )
+    #    status = 'Orden Cancelada'
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2CReceptionRejected.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Cliente desiste'
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.ALASRejected.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'No Entregado'
+
+    elif delivery_order['status'] in [DeliveryOrderStatusType.Steal.value, DeliveryOrderStatusType.Missing.value]:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Mermada'
+
+    else:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+    if events_info:
+        last_event_timestamp = events_info[len(events_info) - 1]['timestamp'].split('.')[0]
+
+    return status, last_event_timestamp
+
 def get_status_info(delivery_order):
     events_info, status, description, last_event_timestamp = None, None, None, None
 
@@ -619,7 +705,7 @@ def get_b2c_delivery_events(delivery_order):
     )
     
 def get_not_delivered_reason(event_info):
-    reasons = ['No hay quien reciba', 'Dirección Incompleta', 'Problema Documentación', 'Siniestro', 'Merma']
+    reasons = ['No hay quien reciba', 'Dirección Incompleta', 'Problema Documentación', 'Código Erróneo', 'Siniestro', 'Merma']
 
     if 'not_delivered_3_reason' in event_info and event_info['not_delivered_3_reason']:
         return reasons[event_info['not_delivered_3_reason'] - 1]
@@ -753,6 +839,12 @@ class DeliveryOrderClient(EntityClientBase):
     def masive_change_b2c_delivery(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_masive_change-b2c-delivery", params)
 
+    def massive_change_b2c_delivery(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_massive_change-b2c-delivery", params)
+
+    def polygons_list(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_polygons-list", params)
+
     def change_destination(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-destination".format(id), params)
 
@@ -802,6 +894,9 @@ class DeliveryOrderClient(EntityClientBase):
 
     def process_physical_reception(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_process-physical-reception", params)
+
+    def process_b2b_receive_reception(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_process-b2b-receive-reception", params)
     
     def slack_report_send(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_slack-report-send", params)
@@ -827,6 +922,9 @@ class DeliveryOrderClient(EntityClientBase):
 
     def delivery_courier_receive(self, id, event_info, pasync=True):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_delivery-courier-receive".format(id), event_info)
+
+    def delivery_courier_assigned(self, id, event_info, pasync=True):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_delivery-courier-assigned".format(id), event_info)
     
     def b2b_travelling(self, id, event_info):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_b2b-travelling".format(id), event_info)
