@@ -7,3 +7,6 @@ class GeographicCoverageClient(EntityClientBase):
     def __init__(self, country_code='cl', **kwargs):
         super(GeographicCoverageClient, self).__init__(**kwargs)
         self.entity_endpoint_base_url += country_code + '/'
+
+    def get_structure_id(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_get-structure-id", params)
